==> vncdotool-0.3.0.tar.gz: vncdotool-0.3.0/setup.py <==
#!/usr/bin/env python

from setuptools import setup

README = open('README.rst', 'rt').read()

setup(
    name='vncdotool',
    version='0.3.0',
    description='Command line VNC client',
    install_requires=[
        'Twisted',
        "PIL",
    ],
    tests_require=[
        'nose',
        'pexpect',
    ],
    url='http://github.com/sibson/vncdotool',
    author='Marc Sibson',
    author_email='sibson+vncdotool@gmail.com',
    download_url='',

    entry_points={
        "console_scripts": [
            'vncdo=vncdotool.command:vncdo',
            'vncdotool=vncdotool.command:vncdo',
            'vnclog=vncdotool.command:vnclog',
        ],
    },
    packages=['vncdotool'],

    classifiers=[
          'Development Status :: 2 - Pre-Alpha',
          'Environment :: Console',
          'Framework :: Twisted',
          'Intended Audience :: Developers',
          'Intended Audience :: System Administrators',
          'License :: OSI Approved :: MIT License',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: Microsoft :: Windows',
          'Operating System :: POSIX',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.4',
          'Programming Language :: Python :: 2.5',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Topic :: Multimedia :: Graphics :: Viewers',
          'Topic :: Software Development :: Testing',
    ],

    long_description=open('README.rst').read(),
)

==> vncdotool-0.8.0.tar.gz: vncdotool-0.8.0/setup.py <==
#!/usr/bin/env python

from setuptools import setup

README = open('README.rst', 'rt').read()

setup(
    name='vncdotool',
    version='0.8.0',
    description='Command line VNC client',
    install_requires=[
        'Twisted',
        "PIL",
    ],
    tests_require=[
        'nose',
        'pexpect',
    ],
    url='http://github.com/sibson/vncdotool',
    author='Marc Sibson',
    author_email='sibson+vncdotool@gmail.com',
    download_url='',

    entry_points={
        "console_scripts": [
            'vncdo=vncdotool.command:vncdo',
            'vncdotool=vncdotool.command:vncdo',
            'vnclog=vncdotool.command:vnclog',
        ],
    },
    packages=['vncdotool'],

    classifiers=[
          'Development Status :: 3 - Alpha',
          'Environment :: Console',
          'Framework :: Twisted',
          'Intended Audience :: Developers',
          'Intended Audience :: System Administrators',
          'License :: OSI Approved :: MIT License',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: Microsoft :: Windows',
          'Operating System :: POSIX',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.4',
          'Programming Language :: Python :: 2.5',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Topic :: Multimedia :: Graphics :: Viewers',
          'Topic :: Software Development :: Testing',
    ],

    long_description=open('README.rst').read(),
)
